.. _markets:

What markets does the platform work with?
=========================================

The platform tracks relevant energy market prices for the user's portfolio of assets.


Day-ahead market
----------------

Defaults:

- Periodicity: daily, weekly, yearly


Tariffs
-------

Defaults:

- Periodicity: none